import gradio as gr
from transformers import pipeline
from gradio.themes.utils import sizes


theme = gr.themes.Default(radius_size=sizes.radius_none).set(
    block_label_text_color = '#4D63FF',
    block_title_text_color = '#4D63FF',
    button_primary_text_color = '#4D63FF',
    button_primary_background_fill='#FFFFFF',
    button_primary_border_color='#4D63FF',
    button_primary_background_fill_hover='#EDEFFF',
)

summarizer = pipeline("summarization", model="knkarthick/bart-large-xsum-samsum")

def summarize(text):
    result = summarizer(text)

    return result[0].get('summary_text')


with gr.Blocks(theme=theme, css="footer {visibility: hidden}") as demo:
    gr.Markdown("""
    <div align='center' ><font size='60'>文本摘要</font></div>
    """)
    with gr.Row():
        with gr.Column():
            box1 = gr.Textbox(label="文本")
            with gr.Row():
                button = gr.Button("提交", variant="primary")
                clear = gr.Button("清除", variant="primary")
        box2 = gr.Textbox(label="文本")

    button.click(fn=summarize, inputs=box1, outputs=box2)
    clear.click(lambda x: gr.update(value=''), [], [box1])
    examples = gr.Examples(examples=['''Hannah: Hey, do you have Betty's number?
Amanda: Lemme check
Amanda: Sorry, can't find it.
Amanda: Ask Larry
Amanda: He called her last time we were at the park together
Hannah: I don't know him well
Amanda: Don't be shy, he's very nice
Hannah: If you say so..
Hannah: I'd rather you texted him
Amanda: Just text him 🙂
Hannah: Urgh.. Alright
Hannah: Bye
Amanda: Bye bye
'''],  inputs=[box1], label="例子")


if __name__ == "__main__":
    demo.queue(concurrency_count=3)
    demo.launch(server_name = "0.0.0.0", server_port = 7028)
